# Summary of Undocumented Objects

- Class Variable - `magneticalc.About_Dialog.About_Dialog.DonationURL`
- Constant - `magneticalc.About_Dialog.About_Dialog.HTML`
- Instance Variable - `magneticalc.About_Dialog.About_Dialog.text_browser`
- Instance Variable - `magneticalc.Assert_Dialog.Assert_Dialog._dialog`
- Instance Variable - `magneticalc.Backend_CUDA.Backend_CUDA._current_elements`
- Instance Variable - `magneticalc.Backend_CUDA.Backend_CUDA._dc`
- Instance Variable - `magneticalc.Backend_CUDA.Backend_CUDA._distance_limit`
- Instance Variable - `magneticalc.Backend_CUDA.Backend_CUDA._field_type`
- Instance Variable - `magneticalc.Backend_CUDA.Backend_CUDA._length_scale`
- Instance Variable - `magneticalc.Backend_CUDA.Backend_CUDA._progress_callback`
- Instance Variable - `magneticalc.Backend_CUDA.Backend_CUDA._sampling_volume_permeabilities`
- Instance Variable - `magneticalc.Backend_CUDA.Backend_CUDA._sampling_volume_points`
- Instance Variable - `magneticalc.Backend_JIT.Backend_JIT._current_elements`
- Instance Variable - `magneticalc.Backend_JIT.Backend_JIT._dc`
- Instance Variable - `magneticalc.Backend_JIT.Backend_JIT._distance_limit`
- Instance Variable - `magneticalc.Backend_JIT.Backend_JIT._field_type`
- Instance Variable - `magneticalc.Backend_JIT.Backend_JIT._length_scale`
- Instance Variable - `magneticalc.Backend_JIT.Backend_JIT._progress_callback`
- Instance Variable - `magneticalc.Backend_JIT.Backend_JIT._sampling_volume_permeabilities`
- Instance Variable - `magneticalc.Backend_JIT.Backend_JIT._sampling_volume_points`
- Class Variable - `magneticalc.CalculationThread.CalculationThread._field_valid`
- Class Variable - `magneticalc.CalculationThread.CalculationThread._metric_valid`
- Class Variable - `magneticalc.CalculationThread.CalculationThread._parameters_valid`
- Class Variable - `magneticalc.CalculationThread.CalculationThread._progress_update`
- Class Variable - `magneticalc.CalculationThread.CalculationThread._sampling_volume_valid`
- Class Variable - `magneticalc.CalculationThread.CalculationThread._wire_valid`
- Instance Variable - `magneticalc.CalculationThread.CalculationThread.gui`
- Instance Variable - `magneticalc.ConditionalDecorator.ConditionalDecorator.condition`
- Instance Variable - `magneticalc.ConditionalDecorator.ConditionalDecorator.decorating_args`
- Instance Variable - `magneticalc.ConditionalDecorator.ConditionalDecorator.decorating_func`
- Class Variable - `magneticalc.Config.Config.DebugAccess`
- Instance Variable - `magneticalc.Config.Config._parser`
- Instance Variable - `magneticalc.Config.Config.filename`
- Instance Variable - `magneticalc.Config.Config.synced`
- Instance Variable - `magneticalc.Config_Group.Config_Collection.first_without_suffix`
- Instance Variable - `magneticalc.Config_Group.Config_Collection.gui`
- Instance Variable - `magneticalc.Config_Group.Config_Collection.prefix`
- Instance Variable - `magneticalc.Config_Group.Config_Collection.types`
- Class Variable - `magneticalc.Constants.Constants.mu_0`
- Class Variable - `magneticalc.Constraint.Constraint.Comparison_Types_Supported`
- Instance Variable - `magneticalc.Constraint.Constraint._comparison_type`
- Instance Variable - `magneticalc.Constraint.Constraint._max`
- Instance Variable - `magneticalc.Constraint.Constraint._min`
- Instance Variable - `magneticalc.Constraint.Constraint._norm_type`
- Instance Variable - `magneticalc.Constraint.Constraint.permeability`
- Class Variable - `magneticalc.Constraint_Editor.Constraint_Editor.Constraint_Options`
- Class Variable - `magneticalc.Constraint_Editor.Constraint_Editor.Constraint_Types`
- Constant - `magneticalc.Constraint_Editor.Constraint_Editor.HTML`
- Instance Variable - `magneticalc.Constraint_Editor.Constraint_Editor._changed`
- Instance Variable - `magneticalc.Constraint_Editor.Constraint_Editor._constraint_collection`
- Instance Variable - `magneticalc.Constraint_Editor.Constraint_Editor.gui`
- Instance Variable - `magneticalc.Constraint_Editor.Constraint_Editor.table`
- Instance Variable - `magneticalc.Constraint_Editor.Constraint_Editor.text_browser`
- Class Variable - `magneticalc.Debug.Debug.Blacklist`
- Class Variable - `magneticalc.Debug.Debug.EnableBlacklist`
- Class Variable - `magneticalc.Debug.Debug.EnableInit`
- Class Variable - `magneticalc.Debug.Debug.EnableRefresh`
- Class Variable - `magneticalc.Display_Widget.Display_Widget.ExcessiveFieldLabelsThreshold`
- Class Variable - `magneticalc.Display_Widget.Display_Widget.FieldArrowHeadScaleMax`
- Class Variable - `magneticalc.Display_Widget.Display_Widget.FieldArrowHeadScaleMin`
- Class Variable - `magneticalc.Display_Widget.Display_Widget.FieldArrowHeadScaleStep`
- Class Variable - `magneticalc.Display_Widget.Display_Widget.FieldArrowLineScaleMax`
- Class Variable - `magneticalc.Display_Widget.Display_Widget.FieldArrowLineScaleMin`
- Class Variable - `magneticalc.Display_Widget.Display_Widget.FieldArrowLineScaleStep`
- Class Variable - `magneticalc.Display_Widget.Display_Widget.FieldBoostMax`
- Class Variable - `magneticalc.Display_Widget.Display_Widget.FieldBoostMin`
- Class Variable - `magneticalc.Display_Widget.Display_Widget.FieldBoostStep`
- Class Variable - `magneticalc.Display_Widget.Display_Widget.FieldPointScaleMax`
- Class Variable - `magneticalc.Display_Widget.Display_Widget.FieldPointScaleMin`
- Class Variable - `magneticalc.Display_Widget.Display_Widget.FieldPointScaleStep`
- Instance Variable - `magneticalc.Display_Widget.Display_Widget.display_field_magnitude_labels_checkbox`
- Instance Variable - `magneticalc.Display_Widget.Display_Widget.field_arrow_head_scale_slider`
- Instance Variable - `magneticalc.Display_Widget.Display_Widget.field_arrow_line_scale_slider`
- Instance Variable - `magneticalc.Display_Widget.Display_Widget.field_boost_slider`
- Instance Variable - `magneticalc.Display_Widget.Display_Widget.field_label_resolution_combobox`
- Instance Variable - `magneticalc.Display_Widget.Display_Widget.field_label_resolution_combobox_connection`
- Instance Variable - `magneticalc.Display_Widget.Display_Widget.field_point_scale_slider`
- Instance Variable - `magneticalc.Display_Widget.Display_Widget.gui`
- Instance Variable - `magneticalc.Display_Widget.Display_Widget.total_labels_label`
- Instance Variable - `magneticalc.ExportContainer_Dialog.ExportContainer_Dialog.Export_Names_Available_Map`
- Instance Variable - `magneticalc.ExportContainer_Dialog.ExportContainer_Dialog.checkboxes`
- Instance Variable - `magneticalc.ExportContainer_Dialog.ExportContainer_Dialog.gui`
- Instance Variable - `magneticalc.Field.Field._distance_limit`
- Instance Variable - `magneticalc.Field.Field._length_scale`
- Instance Variable - `magneticalc.Field.Field._total_calculations`
- Instance Variable - `magneticalc.Field.Field._total_skipped_calculations`
- Instance Variable - `magneticalc.Field.Field._vectors`
- Instance Variable - `magneticalc.Field.Field.type`
- Class Variable - `magneticalc.Field_Widget.Field_Widget.DistanceLimitMax`
- Class Variable - `magneticalc.Field_Widget.Field_Widget.DistanceLimitMin`
- Class Variable - `magneticalc.Field_Widget.Field_Widget.DistanceLimitPrecision`
- Class Variable - `magneticalc.Field_Widget.Field_Widget.DistanceLimitStep`
- Instance Variable - `magneticalc.Field_Widget.Field_Widget.distance_limit_spinbox`
- Instance Variable - `magneticalc.Field_Widget.Field_Widget.field_type_checkboxes`
- Instance Variable - `magneticalc.Field_Widget.Field_Widget.field_type_group`
- Instance Variable - `magneticalc.Field_Widget.Field_Widget.gui`
- Instance Variable - `magneticalc.Field_Widget.Field_Widget.total_calculations_label`
- Instance Variable - `magneticalc.Field_Widget.Field_Widget.total_skipped_calculations_label`
- Instance Variable - `magneticalc.File_Menu.File_Menu.gui`
- Class Variable - `magneticalc.Format.Format.CoordinatePrecision`
- Class Variable - `magneticalc.GUI.GUI.MinimumWindowSize`
- Class Variable - `magneticalc.GUI.GUI.calculation_exited`
- Instance Variable - `magneticalc.GUI.GUI.calculation_start_time`
- Class Variable - `magneticalc.GUI.GUI.calculation_status`
- Instance Variable - `magneticalc.GUI.GUI.calculation_thread`
- Instance Variable - `magneticalc.GUI.GUI.exiting`
- Instance Variable - `magneticalc.GUI.GUI.initializing`
- Class Variable - `magneticalc.GUI.GUI.invalidate_statusbar`
- Instance Variable - `magneticalc.GUI.GUI.menu`
- Instance Variable - `magneticalc.GUI.GUI.model`
- Instance Variable - `magneticalc.GUI.GUI.project`
- Instance Variable - `magneticalc.GUI.GUI.sidebar_left`
- Instance Variable - `magneticalc.GUI.GUI.sidebar_right`
- Instance Variable - `magneticalc.GUI.GUI.splitter`
- Instance Variable - `magneticalc.GUI.GUI.statusbar`
- Instance Variable - `magneticalc.GUI.GUI.user_locale`
- Instance Variable - `magneticalc.GUI.GUI.vispy_canvas`
- Instance Variable - `magneticalc.Help_Menu.Help_Menu.gui`
- Method - `magneticalc.MagnetiCalc_Data.MagnetiCalc_Data.__delitem__`
- Method - `magneticalc.MagnetiCalc_Data.MagnetiCalc_Data.__getitem__`
- Method - `magneticalc.MagnetiCalc_Data.MagnetiCalc_Data.__iter__`
- Method - `magneticalc.MagnetiCalc_Data.MagnetiCalc_Data.__len__`
- Method - `magneticalc.MagnetiCalc_Data.MagnetiCalc_Data.__setitem__`
- Method - `magneticalc.MagnetiCalc_Data.MagnetiCalc_Data._keytransform`
- Instance Variable - `magneticalc.MagnetiCalc_Data.MagnetiCalc_Data.dictionary`
- Instance Variable - `magneticalc.Menu.Menu.file_menu`
- Instance Variable - `magneticalc.Menu.Menu.gui`
- Instance Variable - `magneticalc.Menu.Menu.help_menu`
- Instance Variable - `magneticalc.Menu.Menu.options_menu`
- Instance Variable - `magneticalc.Menu.Menu.view_menu`
- Instance Variable - `magneticalc.Menu.Menu.wire_menu`
- Class Variable - `magneticalc.Metric.Metric.LengthScale`
- Class Variable - `magneticalc.Metric.Metric.LogNormMin`
- Instance Variable - `magneticalc.Metric.Metric._colors`
- Instance Variable - `magneticalc.Metric.Metric._limits`
- Instance Variable - `magneticalc.Metric.Metric.alpha_preset`
- Instance Variable - `magneticalc.Metric.Metric.color_preset`
- Class Variable - `magneticalc.Metric_Presets.Metric_Presets.AngleXY`
- Class Variable - `magneticalc.Metric_Presets.Metric_Presets.AngleXZ`
- Class Variable - `magneticalc.Metric_Presets.Metric_Presets.AngleYZ`
- Class Variable - `magneticalc.Metric_Presets.Metric_Presets.Divergence`
- Class Variable - `magneticalc.Metric_Presets.Metric_Presets.List`
- Class Variable - `magneticalc.Metric_Presets.Metric_Presets.LogDivergence`
- Class Variable - `magneticalc.Metric_Presets.Metric_Presets.LogMagnitude`
- Class Variable - `magneticalc.Metric_Presets.Metric_Presets.LogMagnitudeX`
- Class Variable - `magneticalc.Metric_Presets.Metric_Presets.LogMagnitudeXY`
- Class Variable - `magneticalc.Metric_Presets.Metric_Presets.LogMagnitudeXZ`
- Class Variable - `magneticalc.Metric_Presets.Metric_Presets.LogMagnitudeY`
- Class Variable - `magneticalc.Metric_Presets.Metric_Presets.LogMagnitudeYZ`
- Class Variable - `magneticalc.Metric_Presets.Metric_Presets.LogMagnitudeZ`
- Class Variable - `magneticalc.Metric_Presets.Metric_Presets.Magnitude`
- Class Variable - `magneticalc.Metric_Presets.Metric_Presets.MagnitudeX`
- Class Variable - `magneticalc.Metric_Presets.Metric_Presets.MagnitudeXY`
- Class Variable - `magneticalc.Metric_Presets.Metric_Presets.MagnitudeXZ`
- Class Variable - `magneticalc.Metric_Presets.Metric_Presets.MagnitudeY`
- Class Variable - `magneticalc.Metric_Presets.Metric_Presets.MagnitudeYZ`
- Class Variable - `magneticalc.Metric_Presets.Metric_Presets.MagnitudeZ`
- Class Variable - `magneticalc.Metric_Presets.Metric_Presets.NegDivergence`
- Class Variable - `magneticalc.Metric_Presets.Metric_Presets.NegLogDivergence`
- Class Variable - `magneticalc.Metric_Presets.Metric_Presets.PosDivergence`
- Class Variable - `magneticalc.Metric_Presets.Metric_Presets.PosLogDivergence`
- Class Variable - `magneticalc.Metric_Widget.Metric_Widget.Cool_Gradient_CSS`
- Class Variable - `magneticalc.Metric_Widget.Metric_Widget.HSV_Gradient_CSS`
- Class Variable - `magneticalc.Metric_Widget.Metric_Widget.ValuePrecision`
- Instance Variable - `magneticalc.Metric_Widget.Metric_Widget.alpha_metric_combobox`
- Instance Variable - `magneticalc.Metric_Widget.Metric_Widget.alpha_metric_limits_layout`
- Instance Variable - `magneticalc.Metric_Widget.Metric_Widget.alpha_metric_limits_widget`
- Instance Variable - `magneticalc.Metric_Widget.Metric_Widget.alpha_metric_max_label`
- Instance Variable - `magneticalc.Metric_Widget.Metric_Widget.alpha_metric_min_label`
- Instance Variable - `magneticalc.Metric_Widget.Metric_Widget.color_metric_combobox`
- Instance Variable - `magneticalc.Metric_Widget.Metric_Widget.color_metric_limits_layout`
- Instance Variable - `magneticalc.Metric_Widget.Metric_Widget.color_metric_limits_widget`
- Instance Variable - `magneticalc.Metric_Widget.Metric_Widget.color_metric_max_label`
- Instance Variable - `magneticalc.Metric_Widget.Metric_Widget.color_metric_min_label`
- Instance Variable - `magneticalc.Metric_Widget.Metric_Widget.gui`
- Class Variable - `magneticalc.Model.Model.DebugInvalidate`
- Instance Variable - `magneticalc.Model.Model._field_cache`
- Instance Variable - `magneticalc.Model.Model._field_type_select`
- Instance Variable - `magneticalc.Model.Model.gui`
- Instance Variable - `magneticalc.Model.Model.metric`
- Instance Variable - `magneticalc.Model.Model.parameters`
- Instance Variable - `magneticalc.Model.Model.sampling_volume`
- Instance Variable - `magneticalc.Model.Model.wire`
- Class Variable - `magneticalc.ModelAccess.ModelAccess.DebugValidity`
- Instance Variable - `magneticalc.ModelAccess.ModelAccess._recalculate`
- Instance Variable - `magneticalc.ModelAccess.ModelAccess.gui`
- Method - `magneticalc.Options_Menu.Options_Menu.__init__`
- Instance Variable - `magneticalc.Options_Menu.Options_Menu.backend_actions`
- Instance Variable - `magneticalc.Options_Menu.Options_Menu.gui`
- Instance Variable - `magneticalc.Options_Menu.Options_Menu.options_backend_group`
- Class Variable - `magneticalc.OverridePadding_Dialog.OverridePadding_Dialog.BoundsRange`
- Instance Variable - `magneticalc.OverridePadding_Dialog.OverridePadding_Dialog.bounds_max_spinbox`
- Instance Variable - `magneticalc.OverridePadding_Dialog.OverridePadding_Dialog.bounds_min_spinbox`
- Instance Variable - `magneticalc.OverridePadding_Dialog.OverridePadding_Dialog.buttons`
- Instance Variable - `magneticalc.OverridePadding_Dialog.OverridePadding_Dialog.gui`
- Instance Variable - `magneticalc.Parameters.Parameters._energy`
- Instance Variable - `magneticalc.Parameters.Parameters._magnetic_dipole_moment`
- Instance Variable - `magneticalc.Parameters.Parameters._self_inductance`
- Class Variable - `magneticalc.Parameters_Widget.Parameters_Widget.ValuePrecision`
- Instance Variable - `magneticalc.Parameters_Widget.Parameters_Widget.energy_units_label`
- Instance Variable - `magneticalc.Parameters_Widget.Parameters_Widget.energy_value_label`
- Instance Variable - `magneticalc.Parameters_Widget.Parameters_Widget.gui`
- Instance Variable - `magneticalc.Parameters_Widget.Parameters_Widget.magnetic_dipole_moment_units_label`
- Instance Variable - `magneticalc.Parameters_Widget.Parameters_Widget.magnetic_dipole_moment_value_label`
- Instance Variable - `magneticalc.Parameters_Widget.Parameters_Widget.self_inductance_units_label`
- Instance Variable - `magneticalc.Parameters_Widget.Parameters_Widget.self_inductance_value_label`
- Instance Variable - `magneticalc.Parameters_Widget.Parameters_Widget.wire_length_units_label`
- Instance Variable - `magneticalc.Parameters_Widget.Parameters_Widget.wire_length_value_label`
- Class Variable - `magneticalc.Perspective_Presets.Perspective_Presets.Isometric`
- Class Variable - `magneticalc.Perspective_Presets.Perspective_Presets.List`
- Class Variable - `magneticalc.Perspective_Presets.Perspective_Presets.PlaneXY`
- Class Variable - `magneticalc.Perspective_Presets.Perspective_Presets.PlaneXZ`
- Class Variable - `magneticalc.Perspective_Presets.Perspective_Presets.PlaneYZ`
- Instance Variable - `magneticalc.Perspective_Widget.Perspective_Widget.gui`
- Instance Variable - `magneticalc.Project.Project.gui`
- Instance Variable - `magneticalc.QCheckboxConfig.QCheckboxConfig.actions`
- Instance Variable - `magneticalc.QCheckboxConfig.QCheckboxConfig.gui`
- Instance Variable - `magneticalc.QMessageBox2.QMessageBox2.choice`
- Instance Variable - `magneticalc.QTableView2.QTableView2._allow_delete`
- Instance Variable - `magneticalc.QTableView2.QTableView2._col_keys`
- Instance Variable - `magneticalc.QTableView2.QTableView2._col_options`
- Instance Variable - `magneticalc.QTableView2.QTableView2._col_types`
- Instance Variable - `magneticalc.QTableView2.QTableView2._on_cell_edited`
- Instance Variable - `magneticalc.QTableView2.QTableView2._on_row_deleted`
- Instance Variable - `magneticalc.QTableView2.QTableView2._on_selection_changed`
- Instance Variable - `magneticalc.QTableView2.QTableView2._row_count_minimum`
- Instance Variable - `magneticalc.QTableView2.QTableView2._row_prefix`
- Instance Variable - `magneticalc.QTableView2.QTableView2.gui`
- Instance Variable - `magneticalc.QTableView2.TableModel._col_is_widget`
- Instance Variable - `magneticalc.QTableView2.TableModel._col_keys`
- Instance Variable - `magneticalc.QTableView2.TableModel._data`
- Instance Variable - `magneticalc.QTableView2.TableModel._row_keys`
- Instance Variable - `magneticalc.QtWidgets2.QButtons.QButtons.dictionary`
- Instance Variable - `magneticalc.QtWidgets2.QDialog2.QDialog2.user_accepted`
- Class Variable - `magneticalc.QtWidgets2.QHLine.QHLine.VerticalSpacing`
- Class Variable - `magneticalc.QtWidgets2.QIconLabel.QIconLabel.HorizontalSpacing`
- Class Variable - `magneticalc.QtWidgets2.QLabel2.QLabel2.DebugLabels`
- Instance Variable - `magneticalc.QtWidgets2.QLayouted.QLayouted._layout`
- Instance Variable - `magneticalc.QtWidgets2.QSaveAction.QSaveAction.filename`
- Instance Variable - `magneticalc.QtWidgets2.QSliderFloat.QSliderFloat._step`
- Instance Variable - `magneticalc.SamplingVolume.SamplingVolume._bounds_max`
- Instance Variable - `magneticalc.SamplingVolume.SamplingVolume._bounds_min`
- Instance Variable - `magneticalc.SamplingVolume.SamplingVolume._constraints`
- Instance Variable - `magneticalc.SamplingVolume.SamplingVolume._dimension`
- Instance Variable - `magneticalc.SamplingVolume.SamplingVolume._label_resolution`
- Instance Variable - `magneticalc.SamplingVolume.SamplingVolume._labeled_indices`
- Instance Variable - `magneticalc.SamplingVolume.SamplingVolume._neighbor_indices`
- Instance Variable - `magneticalc.SamplingVolume.SamplingVolume._permeabilities`
- Instance Variable - `magneticalc.SamplingVolume.SamplingVolume._points`
- Instance Variable - `magneticalc.SamplingVolume.SamplingVolume.resolution`
- Class Variable - `magneticalc.SamplingVolume_Widget.SamplingVolume_Widget.PaddingMax`
- Class Variable - `magneticalc.SamplingVolume_Widget.SamplingVolume_Widget.PaddingMin`
- Class Variable - `magneticalc.SamplingVolume_Widget.SamplingVolume_Widget.ResolutionOptionsDict`
- Class Variable - `magneticalc.SamplingVolume_Widget.SamplingVolume_Widget.UnitsLabelWidth`
- Instance Variable - `magneticalc.SamplingVolume_Widget.SamplingVolume_Widget.constraint_editor`
- Instance Variable - `magneticalc.SamplingVolume_Widget.SamplingVolume_Widget.gui`
- Instance Variable - `magneticalc.SamplingVolume_Widget.SamplingVolume_Widget.padding_spinbox`
- Instance Variable - `magneticalc.SamplingVolume_Widget.SamplingVolume_Widget.padding_widget`
- Instance Variable - `magneticalc.SamplingVolume_Widget.SamplingVolume_Widget.resolution_combobox`
- Instance Variable - `magneticalc.SamplingVolume_Widget.SamplingVolume_Widget.resolution_units_label`
- Instance Variable - `magneticalc.SamplingVolume_Widget.SamplingVolume_Widget.total_constraints_label`
- Instance Variable - `magneticalc.SamplingVolume_Widget.SamplingVolume_Widget.total_extent_label`
- Instance Variable - `magneticalc.SamplingVolume_Widget.SamplingVolume_Widget.total_points_label`
- Class Variable - `magneticalc.SidebarLeft.SidebarLeft.MaximumWidth`
- Class Variable - `magneticalc.SidebarLeft.SidebarLeft.VerticalSpacing`
- Instance Variable - `magneticalc.SidebarLeft.SidebarLeft.gui`
- Instance Variable - `magneticalc.SidebarLeft.SidebarLeft.sampling_volume_widget`
- Instance Variable - `magneticalc.SidebarLeft.SidebarLeft.wire_widget`
- Class Variable - `magneticalc.SidebarRight.SidebarRight.MaximumWidth`
- Class Variable - `magneticalc.SidebarRight.SidebarRight.VerticalSpacing`
- Instance Variable - `magneticalc.SidebarRight.SidebarRight.display_widget`
- Instance Variable - `magneticalc.SidebarRight.SidebarRight.field_widget`
- Instance Variable - `magneticalc.SidebarRight.SidebarRight.gui`
- Instance Variable - `magneticalc.SidebarRight.SidebarRight.metric_widget`
- Instance Variable - `magneticalc.SidebarRight.SidebarRight.parameters_widget`
- Instance Variable - `magneticalc.SidebarRight.SidebarRight.perspective_widget`
- Instance Variable - `magneticalc.Statusbar.Statusbar._auto_calculation_checkbox`
- Instance Variable - `magneticalc.Statusbar.Statusbar._cancel_button`
- Instance Variable - `magneticalc.Statusbar.Statusbar._canceled`
- Instance Variable - `magneticalc.Statusbar.Statusbar._cores_combobox`
- Instance Variable - `magneticalc.Statusbar.Statusbar._label`
- Instance Variable - `magneticalc.Statusbar.Statusbar._progressbar`
- Instance Variable - `magneticalc.Statusbar.Statusbar._start_button`
- Instance Variable - `magneticalc.Statusbar.Statusbar._valid`
- Instance Variable - `magneticalc.Statusbar.Statusbar.gui`
- Instance Variable - `magneticalc.Statusbar.Statusbar.layout`
- Class Variable - `magneticalc.Theme.Theme.DarkColor`
- Class Variable - `magneticalc.Theme.Theme.DefaultFontFace`
- Class Variable - `magneticalc.Theme.Theme.DialogTextColor`
- Class Variable - `magneticalc.Theme.Theme.FailureColor`
- Class Variable - `magneticalc.Theme.Theme.LiteColor`
- Class Variable - `magneticalc.Theme.Theme.MainColor`
- Class Variable - `magneticalc.Theme.Theme.QuestionColor`
- Class Variable - `magneticalc.Theme.Theme.SuccessColor`
- Constant - `magneticalc.Usage_Dialog.Usage_Dialog.HTML`
- Instance Variable - `magneticalc.Validatable.Validatable._valid`
- Class Variable - `magneticalc.Version.Version.Copyright`
- Class Variable - `magneticalc.Version.Version.License`
- Class Variable - `magneticalc.Version.Version.String`
- Constant - `magneticalc.Version.__PYPI_SIMPLE__URL__`
- Constant - `magneticalc.Version.__URL__`
- Constant - `magneticalc.Version.__VERSION__`
- Instance Variable - `magneticalc.View_Menu.View_Menu.checkbox_config`
- Instance Variable - `magneticalc.View_Menu.View_Menu.gui`
- Class Variable - `magneticalc.VisPyCanvas.VisPyCanvas.Black`
- Class Variable - `magneticalc.VisPyCanvas.VisPyCanvas.DebugPerspective`
- Class Variable - `magneticalc.VisPyCanvas.VisPyCanvas.DebugVisuals`
- Class Variable - `magneticalc.VisPyCanvas.VisPyCanvas.DefaultFontSize`
- Class Variable - `magneticalc.VisPyCanvas.VisPyCanvas.FieldArrowHeadSize`
- Class Variable - `magneticalc.VisPyCanvas.VisPyCanvas.FieldPointSize`
- Class Variable - `magneticalc.VisPyCanvas.VisPyCanvas.MagnitudeLimit`
- Class Variable - `magneticalc.VisPyCanvas.VisPyCanvas.MagnitudePrecision`
- Class Variable - `magneticalc.VisPyCanvas.VisPyCanvas.ScaleFactorMax`
- Class Variable - `magneticalc.VisPyCanvas.VisPyCanvas.ScaleFactorMin`
- Class Variable - `magneticalc.VisPyCanvas.VisPyCanvas.White`
- Class Variable - `magneticalc.VisPyCanvas.VisPyCanvas.WirePointSelectedColor`
- Class Variable - `magneticalc.VisPyCanvas.VisPyCanvas.WirePointSelectedSize`
- Class Variable - `magneticalc.VisPyCanvas.VisPyCanvas.WirePointSize`
- Instance Variable - `magneticalc.VisPyCanvas.VisPyCanvas.background`
- Instance Variable - `magneticalc.VisPyCanvas.VisPyCanvas.bgcolor`
- Instance Variable - `magneticalc.VisPyCanvas.VisPyCanvas.font_manager`
- Instance Variable - `magneticalc.VisPyCanvas.VisPyCanvas.foreground`
- Instance Variable - `magneticalc.VisPyCanvas.VisPyCanvas.gui`
- Instance Variable - `magneticalc.VisPyCanvas.VisPyCanvas.initializing`
- Instance Variable - `magneticalc.VisPyCanvas.VisPyCanvas.redraw_start_time`
- Instance Variable - `magneticalc.VisPyCanvas.VisPyCanvas.signals_blocked`
- Instance Variable - `magneticalc.VisPyCanvas.VisPyCanvas.super_perspective_changed`
- Instance Variable - `magneticalc.VisPyCanvas.VisPyCanvas.view_main`
- Instance Variable - `magneticalc.VisPyCanvas.VisPyCanvas.view_text`
- Instance Variable - `magneticalc.VisPyCanvas.VisPyCanvas.visual_coordinate_system`
- Instance Variable - `magneticalc.VisPyCanvas.VisPyCanvas.visual_field_arrow_heads`
- Instance Variable - `magneticalc.VisPyCanvas.VisPyCanvas.visual_field_arrow_lines`
- Instance Variable - `magneticalc.VisPyCanvas.VisPyCanvas.visual_field_labels`
- Instance Variable - `magneticalc.VisPyCanvas.VisPyCanvas.visual_field_points`
- Instance Variable - `magneticalc.VisPyCanvas.VisPyCanvas.visual_perspective_info`
- Instance Variable - `magneticalc.VisPyCanvas.VisPyCanvas.visual_startup_info`
- Instance Variable - `magneticalc.VisPyCanvas.VisPyCanvas.visual_wire_points_selected`
- Instance Variable - `magneticalc.VisPyCanvas.VisPyCanvas.visual_wire_points_sliced`
- Instance Variable - `magneticalc.VisPyCanvas.VisPyCanvas.visual_wire_segments`
- Instance Variable - `magneticalc.Wire.Wire._elements`
- Instance Variable - `magneticalc.Wire.Wire._points_sliced`
- Instance Variable - `magneticalc.Wire.Wire._slicer_limit`
- Instance Variable - `magneticalc.Wire.Wire.bounds`
- Instance Variable - `magneticalc.Wire.Wire.dc`
- Instance Variable - `magneticalc.Wire.Wire.points_base`
- Instance Variable - `magneticalc.Wire_Menu.Wire_Menu.export_wire_action`
- Instance Variable - `magneticalc.Wire_Menu.Wire_Menu.gui`
- Instance Variable - `magneticalc.Wire_Menu.Wire_Menu.import_wire_action`
- Class Variable - `magneticalc.Wire_Presets.Wire_Presets.CompensatedDoubleSquareLoop_Centered`
- Class Variable - `magneticalc.Wire_Presets.Wire_Presets.CompensatedDoubleSquareLoop_Offset`
- Class Variable - `magneticalc.Wire_Presets.Wire_Presets.CompensatedSolenoidCircularLoops4`
- Class Variable - `magneticalc.Wire_Presets.Wire_Presets.CompensatedSolenoidCircularLoops8`
- Class Variable - `magneticalc.Wire_Presets.Wire_Presets.List`
- Class Variable - `magneticalc.Wire_Presets.Wire_Presets.PhaseJumpingToroidalLoop16`
- Class Variable - `magneticalc.Wire_Presets.Wire_Presets.PhaseJumpingToroidalLoop32HiRes`
- Class Variable - `magneticalc.Wire_Presets.Wire_Presets.PhaseJumpingToroidalLoop32HiResFlat`
- Class Variable - `magneticalc.Wire_Presets.Wire_Presets.PhaseJumpingToroidalLoop32LoRes`
- Class Variable - `magneticalc.Wire_Presets.Wire_Presets.PhaseJumpingToroidalLoop32LoResFlat`
- Class Variable - `magneticalc.Wire_Presets.Wire_Presets.PhaseJumpingToroidalLoop8`
- Class Variable - `magneticalc.Wire_Presets.Wire_Presets.SingleCircularLoop_Offset`
- Class Variable - `magneticalc.Wire_Presets.Wire_Presets.SingleSquareLoop_Centered`
- Class Variable - `magneticalc.Wire_Presets.Wire_Presets.SingleSquareLoop_Offset`
- Class Variable - `magneticalc.Wire_Presets.Wire_Presets.SolenoidCircularLoops4`
- Class Variable - `magneticalc.Wire_Presets.Wire_Presets.SolenoidCircularLoops8`
- Class Variable - `magneticalc.Wire_Presets.Wire_Presets.StraightLine`
- Class Variable - `magneticalc.Wire_Presets.Wire_Presets.ToroidalLoop16`
- Class Variable - `magneticalc.Wire_Presets.Wire_Presets.ToroidalLoop32HiRes`
- Class Variable - `magneticalc.Wire_Presets.Wire_Presets.ToroidalLoop32HiResFlat`
- Class Variable - `magneticalc.Wire_Presets.Wire_Presets.ToroidalLoop32LoRes`
- Class Variable - `magneticalc.Wire_Presets.Wire_Presets.ToroidalLoop32LoResFlat`
- Class Variable - `magneticalc.Wire_Presets.Wire_Presets.ToroidalLoop8`
- Variable - `magneticalc.Wire_Widget.DefaultRotationalSymmetry`
- Class Variable - `magneticalc.Wire_Widget.Wire_Widget.DcMax`
- Class Variable - `magneticalc.Wire_Widget.Wire_Widget.DcMin`
- Class Variable - `magneticalc.Wire_Widget.Wire_Widget.DcPrecision`
- Class Variable - `magneticalc.Wire_Widget.Wire_Widget.DcStep`
- Class Variable - `magneticalc.Wire_Widget.Wire_Widget.RotationalSymmetryCountMax`
- Class Variable - `magneticalc.Wire_Widget.Wire_Widget.RotationalSymmetryCountMin`
- Class Variable - `magneticalc.Wire_Widget.Wire_Widget.RotationalSymmetryOffsetMax`
- Class Variable - `magneticalc.Wire_Widget.Wire_Widget.RotationalSymmetryOffsetMin`
- Class Variable - `magneticalc.Wire_Widget.Wire_Widget.RotationalSymmetryOffsetPrecision`
- Class Variable - `magneticalc.Wire_Widget.Wire_Widget.RotationalSymmetryOffsetStep`
- Class Variable - `magneticalc.Wire_Widget.Wire_Widget.RotationalSymmetryRadiusMax`
- Class Variable - `magneticalc.Wire_Widget.Wire_Widget.RotationalSymmetryRadiusMin`
- Class Variable - `magneticalc.Wire_Widget.Wire_Widget.RotationalSymmetryRadiusPrecision`
- Class Variable - `magneticalc.Wire_Widget.Wire_Widget.RotationalSymmetryRadiusStep`
- Class Variable - `magneticalc.Wire_Widget.Wire_Widget.SlicerLimitMax`
- Class Variable - `magneticalc.Wire_Widget.Wire_Widget.SlicerLimitMin`
- Class Variable - `magneticalc.Wire_Widget.Wire_Widget.SlicerLimitPrecision`
- Class Variable - `magneticalc.Wire_Widget.Wire_Widget.SlicerLimitStep`
- Class Variable - `magneticalc.Wire_Widget.Wire_Widget.StretchMax`
- Class Variable - `magneticalc.Wire_Widget.Wire_Widget.StretchMin`
- Class Variable - `magneticalc.Wire_Widget.Wire_Widget.StretchPrecision`
- Class Variable - `magneticalc.Wire_Widget.Wire_Widget.StretchStep`
- Class Variable - `magneticalc.Wire_Widget.Wire_Widget.UnitsLabelWidth`
- Instance Variable - `magneticalc.Wire_Widget.Wire_Widget.close_loop_checkbox`
- Instance Variable - `magneticalc.Wire_Widget.Wire_Widget.dc_spinbox`
- Instance Variable - `magneticalc.Wire_Widget.Wire_Widget.gui`
- Instance Variable - `magneticalc.Wire_Widget.Wire_Widget.rotational_symmetry_axis_combobox`
- Instance Variable - `magneticalc.Wire_Widget.Wire_Widget.rotational_symmetry_count_spinbox`
- Instance Variable - `magneticalc.Wire_Widget.Wire_Widget.rotational_symmetry_offset_spinbox`
- Instance Variable - `magneticalc.Wire_Widget.Wire_Widget.rotational_symmetry_radius_spinbox`
- Instance Variable - `magneticalc.Wire_Widget.Wire_Widget.sliced_total_label`
- Instance Variable - `magneticalc.Wire_Widget.Wire_Widget.slicer_limit_spinbox`
- Instance Variable - `magneticalc.Wire_Widget.Wire_Widget.stretch_spinbox`
- Instance Variable - `magneticalc.Wire_Widget.Wire_Widget.table`
- Instance Variable - `magneticalc.Wire_Widget.Wire_Widget.table_total_label`
- Instance Variable - `magneticalc.Wire_Widget.Wire_Widget.transformed_total_label`